@@ -18,11 +18,11 @@
 #include <QtGui>
 #include "interval.h"
 #include "intervalwindow.h"
-//#include "ui_intervalwindow.h"
 #include "camerainterface.h"
 
 Q_IMPORT_PLUGIN(exampleplugin)
 Q_IMPORT_PLUGIN(n900plugin)
+Q_IMPORT_PLUGIN(irplugin)
 
 int main(int argv, char *args[])
 {
@@ -31,13 +31,7 @@ int main(int argv, char *args[])
     QCoreApplication::setOrganizationName("Tx");
     QCoreApplication::setOrganizationDomain("tonet.org");
     QCoreApplication::setApplicationName(APPNAME);
-    /*
-    QMainWindow *widget = new QMainWindow;
-     Ui::MainWindow ui;
-     ui.setupUi(widget);
 
-     widget->show();
-*/
     Interval *model = new Interval();
     IntervalWindow window(model);
     window.show();
